==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/standbypool/kotlin/outputs/GetStandbyContainerGroupPoolResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.standbypool.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * A StandbyContainerGroupPoolResource.
 * @property containerGroupProperties Specifies container group properties of standby container group pools.
 * @property elasticityProfile Specifies elasticity profile of standby container group pools.
 * @property id Fully qualified resource ID for the resource. E.g. "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}"
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetStandbyContainerGroupPoolResult(
    public val containerGroupProperties: ContainerGroupPropertiesResponse,
    public val elasticityProfile: StandbyContainerGroupPoolElasticityProfileResponse,
    public val id: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.standbypool.outputs.GetStandbyContainerGroupPoolResult):
            GetStandbyContainerGroupPoolResult = GetStandbyContainerGroupPoolResult(
            containerGroupProperties = javaType.containerGroupProperties().let({ args0 ->
                com.pulumi.azurenative.standbypool.kotlin.outputs.ContainerGroupPropertiesResponse.Companion.toKotlin(args0)
            }),
            elasticityProfile = javaType.elasticityProfile().let({ args0 ->
                com.pulumi.azurenative.standbypool.kotlin.outputs.StandbyContainerGroupPoolElasticityProfileResponse.Companion.toKotlin(args0)
            }),
            id = javaType.id(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.standbypool.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/standbypool/kotlin/outputs/GetStandbyContainerGroupPoolResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.standbypool.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * A StandbyContainerGroupPoolResource.
 * @property containerGroupProperties Specifies container group properties of standby container group pools.
 * @property elasticityProfile Specifies elasticity profile of standby container group pools.
 * @property id Fully qualified resource ID for the resource. E.g. "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}"
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetStandbyContainerGroupPoolResult(
    public val containerGroupProperties: ContainerGroupPropertiesResponse,
    public val elasticityProfile: StandbyContainerGroupPoolElasticityProfileResponse,
    public val id: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.standbypool.outputs.GetStandbyContainerGroupPoolResult): GetStandbyContainerGroupPoolResult = GetStandbyContainerGroupPoolResult(
            containerGroupProperties = javaType.containerGroupProperties().let({ args0 ->
                com.pulumi.azurenative.standbypool.kotlin.outputs.ContainerGroupPropertiesResponse.Companion.toKotlin(args0)
            }),
            elasticityProfile = javaType.elasticityProfile().let({ args0 ->
                com.pulumi.azurenative.standbypool.kotlin.outputs.StandbyContainerGroupPoolElasticityProfileResponse.Companion.toKotlin(args0)
            }),
            id = javaType.id(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.standbypool.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
